Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2020-12-07 17:58:06 +0300
committerDavid Crocker <dcrocker@eschertech.com>2020-12-07 17:58:06 +0300
commite12837aead381be919c444f8916b9b49b6919ed6 (patch)
tree09e222f797381a24d020cd87e180a148229f0ebf /src/Storage/FileInfoParser.h
parent883c57bdc54301fa5f6386bb6412f6f5a3618005 (diff)
Tidied up return codes from GetFileInfo
Diffstat (limited to 'src/Storage/FileInfoParser.h')
-rw-r--r--src/Storage/FileInfoParser.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/Storage/FileInfoParser.h b/src/Storage/FileInfoParser.h
index ce46ae9b..e3ff0b6e 100644
--- a/src/Storage/FileInfoParser.h
+++ b/src/Storage/FileInfoParser.h
@@ -8,12 +8,13 @@
#ifndef SRC_STORAGE_FILEINFOPARSER_H_
#define SRC_STORAGE_FILEINFOPARSER_H_
-#include "RepRapFirmware.h"
-#include "GCodes/GCodeFileInfo.h"
+#include <RepRapFirmware.h>
+#include <GCodes/GCodeFileInfo.h>
+#include <GCodes/GCodeResult.h>
#if HAS_MASS_STORAGE
-#include "RTOSIface/RTOSIface.h"
+#include <RTOSIface/RTOSIface.h>
const FilePosition GCODE_HEADER_SIZE = 20000uL; // How many bytes to read from the header - I (DC) have a Kisslicer file with a layer height comment 14Kb from the start
const FilePosition GCODE_FOOTER_SIZE = 400000uL; // How many bytes to read from the footer
@@ -44,8 +45,8 @@ class FileInfoParser
public:
FileInfoParser() noexcept;
- // The following method needs to be called repeatedly until it returns true - this may take a few runs
- bool GetFileInfo(const char *filePath, GCodeFileInfo& info, bool quitEarly) noexcept;
+ // The following method needs to be called repeatedly until it doesn't return GCodeResult::notFinished - this may take a few runs
+ GCodeResult GetFileInfo(const char *filePath, GCodeFileInfo& info, bool quitEarly) noexcept;
static constexpr const char* SimulatedTimeString = "\n; Simulated print time"; // used by FileInfoParser and MassStorage